@@ -3,8 +3,8 @@
   FILE: icalfileset.c
   CREATOR: eric 23 December 1999
   
-  $Id: icalfileset.c,v 1.4 2005/01/12 08:45:34 zucchi Exp $
-  $Locker:  $
+  $Id: icalfileset.c 520 2005-08-24 02:32:23Z zucchi $
+  $Locker$
     
  (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org
 
@@ -772,7 +772,7 @@ icalsetiter icalfileset_begin_component(icalset* set, icalcomponent_kind kind, i
 
             /* add recurrence-id to the component
                if there is a recurrence-id already, remove it, then add the new one */
-            if (prop = icalcomponent_get_first_property(comp, ICAL_RECURRENCEID_PROPERTY))
+            if ((prop = icalcomponent_get_first_property(comp, ICAL_RECURRENCEID_PROPERTY)))
                 icalcomponent_remove_property(comp, prop);
             icalcomponent_add_property(comp, icalproperty_new_recurrenceid(next));
 
@@ -837,7 +837,7 @@ icalcomponent* icalfileset_form_a_matched_recurrence_component(icalsetiter* itr)
 
     /* add recurrence-id to the component
      * if there is a recurrence-id already, remove it, then add the new one */
-    if (prop = icalcomponent_get_first_property(comp, ICAL_RECURRENCEID_PROPERTY))
+    if ((prop = icalcomponent_get_first_property(comp, ICAL_RECURRENCEID_PROPERTY)))
         icalcomponent_remove_property(comp, prop);
         icalcomponent_add_property(comp, icalproperty_new_recurrenceid(next));
 
@@ -906,7 +906,7 @@ icalcomponent* icalfilesetiter_to_next(icalset* set, icalsetiter* i)
 
         /* add recurrence-id to the component
          * if there is a recurrence-id already, remove it, then add the new one */
-        if (prop = icalcomponent_get_first_property(c, ICAL_RECURRENCEID_PROPERTY))
+        if ((prop = icalcomponent_get_first_property(c, ICAL_RECURRENCEID_PROPERTY)))
             icalcomponent_remove_property(c, prop);
         icalcomponent_add_property(c, icalproperty_new_recurrenceid(next));
 
