@@ -23,19 +23,20 @@
 #include <config.h>
 #endif
 
+#include <ctype.h>
+#include <errno.h>
+#include <fcntl.h>
 #include <stdlib.h>
 #include <string.h>
-#include <sys/types.h>
-#include <sys/stat.h>
 #include <unistd.h>
-#include <ctype.h>
-#include <fcntl.h>
-#include <errno.h>
+#include <sys/stat.h>
+#include <sys/types.h>
 
+#include <glib.h>
 #include <glib/gstdio.h>
 
-#include "libedataserver/md5-utils.h"
-#include "libedataserver/e-memory.h"
+#include <libedataserver/e-memory.h>
+#include <libedataserver/md5-utils.h>
 
 #include "camel-file-utils.h"
 #include "camel-private.h"
