@@ -4,7 +4,7 @@
  * Copyright (C) 2003  Ximian, Inc.
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -12,7 +12,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
@@ -82,20 +82,27 @@ void  e_source_set_relative_uri  (ESource      *source,
 				  const char   *relative_uri);
 void  e_source_set_absolute_uri  (ESource      *source,
 				  const char   *absolute_uri);
+void  e_source_set_color_spec    (ESource      *source,
+				  const gchar  *color_spec);
 void  e_source_set_readonly      (ESource      *source,
 				  gboolean      readonly);
+#ifndef EDS_DISABLE_DEPRECATED
 void  e_source_set_color         (ESource      *source,
 				  guint32       color);
 void  e_source_unset_color       (ESource      *source);
+#endif
 
 ESourceGroup *e_source_peek_group         (ESource *source);
 const char   *e_source_peek_uid           (ESource *source);
 const char   *e_source_peek_name          (ESource *source);
 const char   *e_source_peek_relative_uri  (ESource *source);
 const char   *e_source_peek_absolute_uri  (ESource *source);
+const char   *e_source_peek_color_spec    (ESource *source);
 gboolean      e_source_get_readonly       (ESource *source);
+#ifndef EDS_DISABLE_DEPRECATED
 gboolean      e_source_get_color          (ESource *source,
 					   guint32 *color_return);
+#endif
 
 char *e_source_get_uri  (ESource *source);
 
