@@ -109,14 +109,6 @@ e_name_selector_dialog_set_property (GObject *object, guint prop_id,
 /* FIXME: category_list should become part of ENameSelectorDialog structure */
 GList *category_list;
 
-static int
-compare_func (const void *voida, const void *voidb)
-{
-	const char *stringa = voida;
-        const char *stringb = voidb;
-	return g_utf8_collate (stringa, stringb);
-}
-
 static void
 e_name_selector_dialog_populate_categories (ENameSelectorDialog *name_selector_dialog)
 {
@@ -125,9 +117,9 @@ e_name_selector_dialog_populate_categories (ENameSelectorDialog *name_selector_d
 	GList *l;
 	category_option_menu = glade_xml_get_widget (name_selector_dialog->gui, "optionmenu-category");
 
+	/* Categories are already sorted */
 	category_list = e_categories_get_list () ;
-	category_list = g_list_prepend (category_list, "Any Category");
-	g_list_sort (category_list, compare_func);
+	category_list = g_list_prepend (category_list, _("Any Category"));
 
 	category_menu = gtk_menu_new ();
 	l = category_list;
@@ -155,6 +147,8 @@ e_name_selector_dialog_init (ENameSelectorDialog *name_selector_dialog)
 	GtkTreeSelection  *selection;
 	ESourceList       *source_list;
 	char              *gladefile;
+	GConfClient *gconf_client;	
+	char *uid;
 
 	ENameSelectorDialogPrivate *priv = E_NAME_SELECTOR_DIALOG_GET_PRIVATE (name_selector_dialog);
 	priv->destination_index = 0;
@@ -237,9 +231,6 @@ e_name_selector_dialog_init (ENameSelectorDialog *name_selector_dialog)
 
 	widget = e_source_option_menu_new (name_selector_dialog->source_list);
         
-	GConfClient *gconf_client;	
-	char *uid;
-	
 	gconf_client = gconf_client_get_default();
 	uid = gconf_client_get_string (gconf_client, "/apps/evolution/addressbook/display/primary_addressbook",
 			NULL);
@@ -542,7 +533,7 @@ add_section (ENameSelectorDialog *name_selector_dialog,
 	section.remove_button  = GTK_BUTTON (gtk_button_new());
 	section.destination_view = GTK_TREE_VIEW (gtk_tree_view_new ());
 
-	gtk_label_set_mnemonic_widget (GTK_LABEL (section.label), section.destination_view);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (section.label), GTK_WIDGET (section.destination_view));
 
 	if (pango_parse_markup (pretty_name, -1, '_', NULL,
 				&text, NULL, NULL))  {
@@ -788,7 +779,7 @@ search_changed (ENameSelectorDialog *name_selector_dialog)
 	text = gtk_entry_get_text (name_selector_dialog->search_entry);
 	text_escaped = escape_sexp_string (text);
 
-	if ( !strcmp (category,"Any Category")) {
+	if ( !strcmp (category, _("Any Category"))) {
 		query_string = g_strdup_printf ("(or (beginswith \"file_as\" %s) "
 						"    (beginswith \"full_name\" %s) "
 						"    (beginswith \"email\" %s) "
@@ -1198,30 +1189,24 @@ destination_column_formatter (GtkTreeViewColumn *column, GtkCellRenderer *cell,
 {
 	EDestinationStore *destination_store = E_DESTINATION_STORE (model);
 	EDestination      *destination;
-	gchar             *string;
+	GString           *buffer;
 
        	destination = e_destination_store_get_destination (destination_store, iter);
 	g_assert (destination);
 
-	if (e_destination_is_evolution_list (destination)) {
-		if (e_destination_list_show_addresses (destination)) {
-			const gchar *name;
-			const gchar *addresses;
+	buffer = g_string_new (e_destination_get_name (destination));
 
-			name      = e_destination_get_name (destination);
-			addresses = e_destination_get_address (destination);
+	if (!e_destination_is_evolution_list (destination)) {
+		const gchar *email;
 
-			string = g_strdup_printf ("%s%s(%s)", name ? name : "",
-						  name ? " " : "", addresses ? addresses : "?");
-		} else {
-			string = g_strdup (e_destination_get_name (destination));
-		}
-	} else {
-		string = g_strdup (e_destination_get_address (destination));
+		email = e_destination_get_email (destination);
+		if (email == NULL || *email == '\0')
+			email = "?";
+		g_string_append_printf (buffer, " <%s>", email);
 	}
 
-	g_object_set (cell, "text", string, NULL);
-	g_free (string);
+	g_object_set (cell, "text", buffer->str, NULL);
+	g_string_free (buffer, TRUE);
 }
 
 /* ----------------------- *
@@ -1292,7 +1277,7 @@ e_name_selector_dialog_set_destination_index (ENameSelectorDialog *name_selector
  * Widget creation functions for Glade *
  * ----------------------------------- */
 
-#if CATEGORIES_COMPONENTS_MOVED
+#ifdef CATEGORIES_COMPONENTS_MOVED
 
 GtkWidget *
 e_name_selector_dialog_create_categories (void)
